@@ -6,27 +6,21 @@
 #' fit, estimates, smart layout and terminal data.
 #' @export
 #' @examples
-#' fit_tree <- compute_tree(penguins, target_lab = 'species')
+#' fit_tree <- compute_tree(penguins, target_lab = "species")
 #' fit_tree$fit
 #' fit_tree$layout
-#' dplyr::select(fit_tree$term_dat, - contains('nodedata'))
+#' dplyr::select(fit_tree$term_dat, -contains("nodedata"))
 #'
-
-compute_tree <- function(
-  x, data_test = NULL, target_lab = NULL, task = c('classification', 'regression'),
-  feat_types = NULL, label_map = NULL, clust_samps = TRUE, clust_target = TRUE,
-  custom_layout = NULL, lev_fac = 1.3, panel_space = 0.001){
-
+compute_tree <- function(x, data_test = NULL, target_lab = NULL, task = c("classification", "regression"),
+                         feat_types = NULL, label_map = NULL, clust_samps = TRUE, clust_target = TRUE,
+                         custom_layout = NULL, lev_fac = 1.3, panel_space = 0.001) {
   task <- match.arg(task)
-  fit <- get_fit(x = x, data_test = data_test, target_lab = target_lab,
-                 task = task, feat_types = feat_types)
-
-  if ('data.frame' %in% class(x)){
-    fit$autotree <- TRUE
-  } else {
-    fit$autotree <- FALSE
-  }
+  fit <- get_fit(
+    x = x, data_test = data_test, target_lab = target_lab,
+    task = task, feat_types = feat_types
+  )
 
+  fit$autotree <- 'data.frame' %in% class(x)
   dat <- prediction_df(fit, task, clust_samps, clust_target)
 
   ################################################################
@@ -37,22 +31,28 @@ compute_tree <- function(
   terminal_data <- term_node_pos(plot_data, dat)
   layout <- position_nodes(plot_data, terminal_data, custom_layout, lev_fac, panel_space)
 
-  term_dat <- terminal_data %>%
-    select(- c(x, y)) %>%
-    left_join(layout, by = 'id') %>%
-    mutate(term_node = (
-      if (task == 'classification')
-        if (!is.null(label_map))
-          recode(as.factor(y_hat), !!!label_map)
-        else
-          as.factor(y_hat)
-      else
-        round(y_hat, 2)))
+  # browser()
 
-  list(fit = fit,
-       dat = dat,
-       layout = layout,
-       term_dat = term_dat)
+  term_dat <- terminal_data %>%
+    select(-c(x, y)) %>%
+    left_join(layout, by = "id") %>%
+    mutate(term_node = (
+      if (task == "classification") {
+        if (!is.null(label_map)) {
+          recode(as.factor(y_hat), !!!label_map)
+        } else {
+          as.factor(y_hat)
+        }
+      } else {
+        round(y_hat, 2)
+      }))
+
+  list(
+    fit = fit,
+    dat = dat,
+    layout = layout,
+    term_dat = term_dat
+  )
 }
 
 
@@ -67,24 +67,26 @@ compute_tree <- function(
 #' @return A dataframe of prediction values with scaled columns
 #' and clustered samples.
 #'
-prediction_df <- function(fit, task, clust_samps, clust_target){
+prediction_df <- function(fit, task, clust_samps, clust_target) {
   data <- fit$data_test %||% fit$data
   data <- stats::na.omit(data)
-  node_pred <- stats::predict(fit, newdata = data, type = 'node')
-  y_pred <- stats::predict(fit, newdata = data, type = 'response', simplify = FALSE) %>%
+  node_pred <- stats::predict(fit, newdata = data, type = "node")
+  y_pred <- stats::predict(fit, newdata = data, type = "response", simplify = FALSE) %>%
     .simplify_pred(id = node_pred, nam = as.character(node_pred))
 
   data_pred <- data %>%
     cbind(node_id = node_pred, y_hat = y_pred) %>%
     lapply(
-      unique(.$node_id), clust_samp_func, dat = .,
+      unique(.$node_id), clust_samp_func,
+      dat = .,
       clust_vec = if (clust_target) colnames(data) else setdiff(colnames(data), fit$target_lab),
-      clust_samps = clust_samps) %>%
+      clust_samps = clust_samps
+    ) %>%
     bind_rows() %>%
     mutate(Sample = row_number())
 
-  if (task == 'classification'){
-    y_prob <- stats::predict(fit, newdata = data, type = 'prob', simplify = FALSE) %>%
+  if (task == "classification") {
+    y_prob <- stats::predict(fit, newdata = data, type = "prob", simplify = FALSE) %>%
       .simplify_pred(id = node_pred, nam = as.character(node_pred))
     data_pred <- cbind(data_pred, y_prob)
   }
@@ -105,15 +107,15 @@ prediction_df <- function(fit, task, clust_samps, clust_target){
 #'
 #' @return Dataframe with terminal node information.
 #'
-term_node_pos <- function(plot_data, dat){
+term_node_pos <- function(plot_data, dat) {
   node_labels <- dat %>%
     distinct(Sample, .keep_all = T) %>%
     count(node_id, y_hat) %>%
     rename(id = node_id)
 
-  terminal_data <- plot_data %>%
+  plot_data %>%
     filter(kids == 0) %>%
-    left_join(node_labels, by = 'id') %>%
+    left_join(node_labels, by = "id") %>%
     mutate_at(vars(n), ~ replace(., is.na(.), 0))
 }
 
@@ -132,17 +134,16 @@ term_node_pos <- function(plot_data, dat){
 #' @return Dataframe with 3 columns: id, x and y of smart layout
 #' combined with custom_layout.
 #'
-position_nodes <- function(plot_data, terminal_data, custom_layout, lev_fac, panel_space){
-
+position_nodes <- function(plot_data, terminal_data, custom_layout, lev_fac, panel_space) {
   node_size <- terminal_data$n
 
   # Determine terminal node position based on terminal node size:
-  new_x <- vector(mode = 'numeric')
+  new_x <- vector(mode = "numeric")
   for (i in seq_along(terminal_data$id)) {
     i_id <- terminal_data$id[i]
-    raw_pos <- (sum(node_size[0:i]) - node_size[i]/2)/sum(node_size)
+    raw_pos <- (sum(node_size[0:i]) - node_size[i] / 2) / sum(node_size)
     # white space adjusting:
-    new_x[i] <- raw_pos*(1-(nrow(terminal_data) - 1)*panel_space) + (i-1)*panel_space
+    new_x[i] <- raw_pos * (1 - (nrow(terminal_data) - 1) * panel_space) + (i - 1) * panel_space
   }
 
   # Traversing upward to the parents of terminal nodes:
@@ -150,26 +151,26 @@ position_nodes <- function(plot_data, terminal_data, custom_layout, lev_fac, pan
 
   adj_plot_data <- plot_data %>%
     select(id, x, y, parent, level, kids) %>%
-    filter(!id %in%terminal_data$id) %>%
+    filter(!id %in% terminal_data$id) %>%
     bind_rows(traverse)
 
-  while (!is.na(traverse$parent[1])){ # when not at Node 1
+  while (!is.na(traverse$parent[1])) { # when not at Node 1
     # Find pairs of node with the same parents:
     last_lev <- traverse %>%
-      select(- n) %>%
+      select(-n) %>%
       add_count(parent) %>%
       filter(n == 2)
     these_parents <- unique(last_lev$parent)
 
-    for (p in these_parents){ # for each pair
+    for (p in these_parents) { # for each pair
       kids_df <- last_lev[last_lev$parent == p, ]
 
       # weigh kids according to their level
       # so that the parent is closer to the higher level one:
-      kids_df$x_mod <- kids_df$x*lev_fac^kids_df$level/(sum(lev_fac^(kids_df$level)))
+      kids_df$x_mod <- kids_df$x * lev_fac^kids_df$level / (sum(lev_fac^(kids_df$level)))
 
       par_id <- adj_plot_data$id == p
-      adj_plot_data[par_id, 'x'] <- sum(kids_df$x_mod)
+      adj_plot_data[par_id, "x"] <- sum(kids_df$x_mod)
 
       # remove the kids, add the parent
       traverse <- traverse %>%
@@ -178,12 +179,8 @@ position_nodes <- function(plot_data, terminal_data, custom_layout, lev_fac, pan
     }
   }
 
-  my_layout <- adj_plot_data %>%
+  adj_plot_data %>%
     filter(!(id %in% custom_layout$id)) %>%
     select(id, x, y) %>%
     bind_rows(custom_layout)
-
-  return(my_layout)
 }
-
-
