@@ -33,49 +33,88 @@
 #' @return A ggplot2 grob object of the decision tree.
 #' @export
 #' @examples
-#' x <- compute_tree(penguins, target_lab = 'species')
+#' x <- compute_tree(penguins, target_lab = "species")
 #' draw_tree(x$dat, x$fit, x$term_dat, x$layout)
 #'
 draw_tree <- function(
-  dat, fit, term_dat, layout, target_cols = NULL, title = NULL, tree_space_top = 0.05,
-  tree_space_bottom = 0.05, print_eval = FALSE, metrics = NULL, x_eval = 0, y_eval = 0.9,
-  task = c('classification', 'regression'),
+  dat,
+  fit,
+  term_dat,
+  layout,
+  target_cols = NULL,
+  title = NULL,
+  tree_space_top = 0.05,
+  tree_space_bottom = 0.05,
+  print_eval = FALSE,
+  metrics = NULL,
+  x_eval = 0,
+  y_eval = 0.9,
+  task = c("classification", "regression"),
   par_node_vars = list(
-    label.size = 0, # no border around labels, unlike terminal nodes
-    label.padding = unit(0.15, 'lines'),
+    label.padding = unit(0.15, "lines"),
     line_list = list(aes(label = splitvar)),
     line_gpar = list(list(size = 9)),
-    ids = 'inner'),
+    ids = "inner"
+  ),
   terminal_vars = list(
     label.padding = unit(0.25, "lines"),
     size = 3,
-    col = 'white'),
-  edge_vars = list(color = 'grey70', size = 0.5),
+    col = "white"
+  ),
+  edge_vars = list(color = "grey70", linewidth = 0.5),
   edge_text_vars = list(
-    color = 'grey30', size = 3,
-    mapping = aes(label = paste(breaks_label, "*NA")))
-  ){
-
-  text_eval <- if (print_eval){
-    eval_tree(dat, all.vars(stats::update(fit$terms, . ~ 0)), match.arg(task), metrics)
-  } else {''}
+    color = "grey30",
+    size = 3,
+    mapping = aes(label = paste(breaks_label, "*NA"))
+  )
+) {
+  text_eval <- if (print_eval) {
+    eval_tree(
+      dat,
+      all.vars(stats::update(fit$terms, . ~ 0)),
+      match.arg(task),
+      metrics
+    )
+  } else {
+    ""
+  }
 
   ggparty::ggparty(fit, terminal_space = 0, layout = layout) +
     do.call(ggparty::geom_edge, edge_vars) +
     do.call(ggparty::geom_edge_label, edge_text_vars) +
     do.call(ggparty::geom_node_label, par_node_vars) +
-    {if (!is.null(terminal_vars)) do.call(
-      ggparty::geom_node_label,
-      c(list(data = term_dat, mapping = aes(label = term_node, fill = term_node)),
-        terminal_vars))} +
+    {
+      if (!is.null(terminal_vars)) {
+        do.call(
+          ggparty::geom_node_label,
+          c(
+            list(
+              data = term_dat,
+              mapping = aes(label = term_node, fill = term_node)
+            ),
+            terminal_vars
+          )
+        )
+      }
+    } +
     target_cols +
-    scale_x_continuous(expand = c(0,0)) +
+    scale_x_continuous(expand = c(0, 0)) +
     scale_y_continuous(
-      expand = expansion(c(0,0), c(tree_space_bottom, tree_space_top))) +
+      expand = expansion(c(0, 0), c(tree_space_bottom, tree_space_top))
+    ) +
     labs(title = title) +
     coord_cartesian(xlim = c(0, 1)) +
-    guides(fill = FALSE) +
-    {if (print_eval) annotate(
-      'text', x = x_eval, y = y_eval, label = text_eval,
-      hjust = 0, size = edge_text_vars$size %||% 5)}
+    guides(fill = "none") +
+    {
+      if (print_eval) {
+        annotate(
+          "text",
+          x = x_eval,
+          y = y_eval,
+          label = text_eval,
+          hjust = 0,
+          size = edge_text_vars$size %||% 5
+        )
+      }
+    }
 }
