@@ -7,23 +7,21 @@
 #'
 #' @return Character string of the decision tree evaluation.
 #' @export
-#' @examples eval_tree(compute_tree(penguins, target_lab = 'species')$dat)
+#' @examples eval_tree(compute_tree(penguins, target_lab = "species")$dat)
 #'
-eval_tree <- function(
-  dat, target_lab = colnames(dat)[1], task = c('classification', 'regression'),
-  metrics = NULL){
-
+eval_tree <- function(dat, target_lab = colnames(dat)[1], task = c("classification", "regression"),
+                      metrics = NULL) {
   task <- match.arg(task)
-  switch(
-    task,
+  switch(task,
     classification = eval_class(dat, target_lab, metrics),
     regression = eval_reg(dat, target_lab, metrics),
   )
 }
 
-eval_class <- function(dat, target_lab, metrics = NULL){
-  if (!(target_lab %in% colnames(dat) && 'y_hat' %in% colnames(dat)))
-    stop(sprintf('Prediction dataframes must have columns %s and `y_hat`', target_lab))
+eval_class <- function(dat, target_lab, metrics = NULL) {
+  if (!(target_lab %in% colnames(dat) && "y_hat" %in% colnames(dat))) {
+    stop(sprintf("Prediction dataframes must have columns %s and `y_hat`", target_lab))
+  }
 
   # Classification metrics:
   metrics <- metrics %||%
@@ -32,26 +30,30 @@ eval_class <- function(dat, target_lab, metrics = NULL){
       yardstick::bal_accuracy,
       yardstick::kap,
       yardstick::roc_auc,
-      yardstick::pr_auc)
+      yardstick::pr_auc
+    )
 
   my_levs <- levels(dat[, target_lab])
   text_eval <- metrics(
     dat,
-    truth = !! target_lab,
+    truth = !!target_lab,
     estimate = y_hat,
-    !! if (length(my_levs) > 2) my_levs else my_levs[1]) %>%
+    !!if (length(my_levs) > 2) my_levs else my_levs[1]
+  ) %>%
     transmute(print_metric = paste(
       toupper(.metric),
       format(.estimate, digits = 3),
-      sep = ': ')) %>%
+      sep = ": "
+    )) %>%
     pull() %>%
-    paste(collapse = '\n')
+    paste(collapse = "\n")
   text_eval
 }
 
-eval_reg <- function(dat, target_lab, metrics = NULL){
-  if (!(target_lab %in% colnames(dat) && 'y_hat' %in% colnames(dat)))
-    stop(sprintf('Prediction dataframes must have columns %s and `y_hat`', target_lab))
+eval_reg <- function(dat, target_lab, metrics = NULL) {
+  if (!(target_lab %in% colnames(dat) && "y_hat" %in% colnames(dat))) {
+    stop(sprintf("Prediction dataframes must have columns %s and `y_hat`", target_lab))
+  }
 
   # Regression metrics:
   metrics <- metrics %||%
@@ -59,14 +61,16 @@ eval_reg <- function(dat, target_lab, metrics = NULL){
       yardstick::rsq,
       yardstick::mae,
       yardstick::rmse,
-      yardstick::ccc)
+      yardstick::ccc
+    )
 
   text_eval <- metrics(dat, truth = !!target_lab, estimate = y_hat) %>%
     transmute(print_metric = paste(
       toupper(.metric),
       format(.estimate, digits = 3),
-      sep = ': ')) %>%
+      sep = ": "
+    )) %>%
     pull() %>%
-    paste(collapse = '\n')
+    paste(collapse = "\n")
   text_eval
 }
