@@ -7,13 +7,12 @@
 #' @return Numeric vector of the transformed `x`.
 #' @export
 #' @examples scale_norm(1:5)
-#' scale_norm(1:5, 'normalize')
+#' scale_norm(1:5, "normalize")
 #'
-scale_norm <- function(x, trans_type = c('percentize', 'normalize', 'scale', 'none')){
+scale_norm <- function(x, trans_type = c("percentize", "normalize", "scale", "none")) {
   trans_type <- match.arg(trans_type)
 
-  switch(
-    trans_type,
+  switch(trans_type,
     percentize = stats::ecdf(x)(x),
     scale = as.numeric(scale(x)),
     normalize = my_norm(x),
@@ -21,8 +20,8 @@ scale_norm <- function(x, trans_type = c('percentize', 'normalize', 'scale', 'no
   )
 }
 
-my_norm <- function(x){
+my_norm <- function(x) {
   x <- x - min(x, na.rm = T)
-  x <- x/max(x, na.rm = T)
+  x <- x / max(x, na.rm = T)
   x
 }
